Index: code/branches/ScriptableController_FS18/src/orxonox/worldentities/pawns/ScriptableControllerDrone.cc
===================================================================
--- code/branches/ScriptableController_FS18/src/orxonox/worldentities/pawns/AAAAutonomousDrone.cc	(revision 11932)
+++ code/branches/ScriptableController_FS18/src/orxonox/worldentities/pawns/ScriptableControllerDrone.cc	(revision 12006)
@@ -27,5 +27,5 @@
  */
 
-#include "AAAAutonomousDrone.h"
+#include "ScriptableControllerDrone.h"
 
 #include "core/CoreIncludes.h"
@@ -44,12 +44,12 @@
     */
 
-    RegisterClass(AAAAutonomousDrone);
+    RegisterClass(ScriptableControllerDrone);
     
-    AAAAutonomousDrone::AAAAutonomousDrone(Context* context) : Pawn(context)
+    ScriptableControllerDrone::ScriptableControllerDrone(Context* context) : Pawn(context)
     {
         //TODO: Put your code in here:
         // Register the drone class to the core.
 
-	RegisterObject(AAAAutonomousDrone);
+	RegisterObject(ScriptableControllerDrone);
       
         //this->myController_ = NULL;
@@ -70,5 +70,5 @@
         //this->setCollisionType(CollisionType::Dynamic);
 
-        //this->myController_ = new AAAAutonomousDroneController(this); // Creates a new controller and passes our this pointer to it as creator.
+        //this->myController_ = new ScriptableControllerDroneController(this); // Creates a new controller and passes our this pointer to it as creator.
     }
 
@@ -77,5 +77,5 @@
         Destructor. Destroys controller, if present.
     */
-    AAAAutonomousDrone::~AAAAutonomousDrone()
+    ScriptableControllerDrone::~ScriptableControllerDrone()
     {
         // Deletes the controller if the object was initialized and the pointer to the controller is not NULL.
@@ -86,22 +86,22 @@
     /**
     @brief
-        Method for creating a AAAAutonomousDrone through XML.
-    */
-    void AAAAutonomousDrone::XMLPort(Element& xmlelement, XMLPort::Mode mode)
+        Method for creating a ScriptableControllerDrone through XML.
+    */
+    void ScriptableControllerDrone::XMLPort(Element& xmlelement, XMLPort::Mode mode)
     {
         // This calls the XMLPort function of the parent class
-        SUPER(AAAAutonomousDrone, XMLPort, xmlelement, mode);
-
-        XMLPortParam(AAAAutonomousDrone, "primaryThrust", setPrimaryThrust, getPrimaryThrust, xmlelement, mode);
+        SUPER(ScriptableControllerDrone, XMLPort, xmlelement, mode);
+
+        XMLPortParam(ScriptableControllerDrone, "primaryThrust", setPrimaryThrust, getPrimaryThrust, xmlelement, mode);
         //TODO: Put your code in here:
         // Make sure you add the variables auxiliaryThrust_ and rotationThrust_ to XMLPort.
         // Variables can be added by the following command
         // XMLPortParam(Classname, "xml-attribute-name (i.e. variablename)", setFunctionName, getFunctionName, xmlelement, mode);
-        // Also make sure that you also create the get- and set-functions in AAAAutonomousDrone.h. As you can see, the get- and set-functions for the variable primaryThrust_ has already been specified there, so you can get your inspiration from there.
-        XMLPortParam(AAAAutonomousDrone, "auxiliaryThrust", setAuxiliaryThrust, getAuxiliaryThrust, xmlelement, mode);
-    XMLPortParam(AAAAutonomousDrone, "rotationThrust", setRotationThrust, getRotationThrust, xmlelement, mode);
-	XMLPortParam(AAAAutonomousDrone, "mass", setMass, getMass, xmlelement, mode);
-	XMLPortParam(AAAAutonomousDrone, "linearDamping", setLinearDamping, getLinearDamping, xmlelement, mode);
-	XMLPortParam(AAAAutonomousDrone, "angularDamping", setAngularDamping, getAngularDamping, xmlelement, mode);
+        // Also make sure that you also create the get- and set-functions in ScriptableControllerDrone.h. As you can see, the get- and set-functions for the variable primaryThrust_ has already been specified there, so you can get your inspiration from there.
+        XMLPortParam(ScriptableControllerDrone, "auxiliaryThrust", setAuxiliaryThrust, getAuxiliaryThrust, xmlelement, mode);
+    XMLPortParam(ScriptableControllerDrone, "rotationThrust", setRotationThrust, getRotationThrust, xmlelement, mode);
+	XMLPortParam(ScriptableControllerDrone, "mass", setMass, getMass, xmlelement, mode);
+	XMLPortParam(ScriptableControllerDrone, "linearDamping", setLinearDamping, getLinearDamping, xmlelement, mode);
+	XMLPortParam(ScriptableControllerDrone, "angularDamping", setAngularDamping, getAngularDamping, xmlelement, mode);
 
    
@@ -113,11 +113,11 @@
     /**
     @brief
-        Defines which actions the AAAAutonomousDrone has to take in each tick.
+        Defines which actions the ScriptableControllerDrone has to take in each tick.
     @param dt
         The length of the tick.
     */
-    void AAAAutonomousDrone::tick(float dt)
-    {
-        SUPER(AAAAutonomousDrone, tick, dt);
+    void ScriptableControllerDrone::tick(float dt)
+    {
+        SUPER(ScriptableControllerDrone, tick, dt);
 
 
@@ -141,9 +141,9 @@
     /**
     @brief
-        Moves the AAAAutonomousDrone in the negative z-direction (Front/Back) by an amount specified by the first component of the input 2-dim vector.
+        Moves the ScriptableControllerDrone in the negative z-direction (Front/Back) by an amount specified by the first component of the input 2-dim vector.
     @param value
         The vector determining the amount of the movement.
     */
-    void AAAAutonomousDrone::moveFrontBack(const Vector2& value)
+    void ScriptableControllerDrone::moveFrontBack(const Vector2& value)
     {
         this->localLinearAcceleration_.setZ(this->localLinearAcceleration_.z() - value.x);
@@ -152,9 +152,9 @@
     /**
     @brief
-        Moves the AAAAutonomousDrone in the x-direction (Right/Left) by an amount specified by the first component of the input 2-dim vector.
+        Moves the ScriptableControllerDrone in the x-direction (Right/Left) by an amount specified by the first component of the input 2-dim vector.
     @param value
         The vector determining the amount of the movement.
     */
-    void AAAAutonomousDrone::moveRightLeft(const Vector2& value)
+    void ScriptableControllerDrone::moveRightLeft(const Vector2& value)
     {
         this->localLinearAcceleration_.setX(this->localLinearAcceleration_.x() + value.x);
@@ -163,9 +163,9 @@
     /**
     @brief
-        Moves the AAAAutonomousDrone in the y-direction (Up/Down) by an amount specified by the first component of the input 2-dim vector.
+        Moves the ScriptableControllerDrone in the y-direction (Up/Down) by an amount specified by the first component of the input 2-dim vector.
     @param value
         The vector determining the amount of the movement.
     */
-    void AAAAutonomousDrone::moveUpDown(const Vector2& value)
+    void ScriptableControllerDrone::moveUpDown(const Vector2& value)
     {
         this->localLinearAcceleration_.setY(this->localLinearAcceleration_.y() + value.x);
@@ -174,9 +174,9 @@
     /**
     @brief
-        Rotates the AAAAutonomousDrone around the y-axis by the amount specified by the first component of the input 2-dim vector.
+        Rotates the ScriptableControllerDrone around the y-axis by the amount specified by the first component of the input 2-dim vector.
     @param value
         The vector determining the amount of the angular movement.
     */
-    void AAAAutonomousDrone::rotateYaw(const Vector2& value)
+    void ScriptableControllerDrone::rotateYaw(const Vector2& value)
     {
         this->localAngularAcceleration_.setY(this->localAngularAcceleration_.y() - value.x);
@@ -185,9 +185,9 @@
     /**
     @brief
-        Rotates the AAAAutonomousDrone around the x-axis by the amount specified by the first component of the input 2-dim vector.
+        Rotates the ScriptableControllerDrone around the x-axis by the amount specified by the first component of the input 2-dim vector.
     @param value
         The vector determining the amount of the angular movement.
     */
-    void AAAAutonomousDrone::rotatePitch(const Vector2& value)
+    void ScriptableControllerDrone::rotatePitch(const Vector2& value)
     {
         this->localAngularAcceleration_.setX(this->localAngularAcceleration_.x() + value.x);
@@ -196,9 +196,9 @@
     /**
     @brief
-        Rotates the AAAAutonomousDrone around the z-axis by the amount specified by the first component of the input 2-dim vector.
+        Rotates the ScriptableControllerDrone around the z-axis by the amount specified by the first component of the input 2-dim vector.
     @param value
         The vector determining the amount of the angular movement.
     */
-    void AAAAutonomousDrone::rotateRoll(const Vector2& value)
+    void ScriptableControllerDrone::rotateRoll(const Vector2& value)
     {
         this->localAngularAcceleration_.setZ(this->localAngularAcceleration_.z() + value.x);
